@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: associate.php 3336 2007-06-13 09:26:06Z glen $
+// @(#) $Id: associate.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "db_access.php");
@@ -43,31 +44,31 @@ Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 
 if (@$_POST['cat'] == 'associate') {
     if ($_POST['target'] == 'email') {
-        $res = Support::associate(Auth::getUserID(), $_POST['issue'], $_POST['item']);
+        $res = Support::associate(Auth::getUserID(), $_POST['issue_id'], $_POST['item']);
         if ($res == 1) {
-            Workflow::handleManualEmailAssociation(Issue::getProjectID($_POST['issue']), $_POST['issue']);
+            Workflow::handleManualEmailAssociation(Issue::getProjectID($_POST['issue_id']), $_POST['issue_id']);
         }
         $tpl->assign("associate_result", $res);
     } elseif ($_POST['target'] == 'reference') {
-        $res = Support::associateEmail(Auth::getUserID(), $_POST['issue'], $_POST['item']);
+        $res = Support::associateEmail(Auth::getUserID(), $_POST['issue_id'], $_POST['item']);
         if ($res == 1) {
-            Workflow::handleManualEmailAssociation(Issue::getProjectID($_POST['issue']), $_POST['issue']);
+            Workflow::handleManualEmailAssociation(Issue::getProjectID($_POST['issue_id']), $_POST['issue_id']);
         }
         $tpl->assign("associate_result", $res);
     } else {
         for ($i = 0; $i < count($_POST['item']); $i++) {
             $email = Support::getEmailDetails(Email_Account::getAccountByEmail($_POST['item'][$i]), $_POST['item'][$i]);
             // add the message body as a note
-            $_POST['blocked_msg'] = $email['seb_full_email'];
+            $_POST['full_message'] = $email['seb_full_email'];
             $_POST['title'] = $email['sup_subject'];
             $_POST['note'] = $email['seb_body'];
-            // XXX: probably broken to use the current logged in user as the 'owner' of 
+            // XXX: probably broken to use the current logged in user as the 'owner' of
             // XXX: this new note, but that's how it was already
-            $res = Note::insert(Auth::getUserID(), $_POST['issue']);
+            $res = Note::insert(Auth::getUserID(), $_POST['issue_id'], false, true, false, true, true);
             // remove the associated email
             if ($res) {
                 list($_POST["from"]) = Support::getSender(array($_POST['item'][$i]));
-                Workflow::handleBlockedEmail(Issue::getProjectID($_POST['issue']), $_POST['issue'], $_POST, 'associated');
+                Workflow::handleBlockedEmail(Issue::getProjectID($_POST['issue_id']), $_POST['issue_id'], $_POST, 'associated');
                 Support::removeEmail($_POST['item'][$i]);
             }
         }
@@ -77,7 +78,7 @@ if (@$_POST['cat'] == 'associate') {
 } else {
     @$tpl->assign('emails', $_GET['item']);
     @$tpl->assign('total_emails', count($_GET['item']));
-    $prj_id = Issue::getProjectID($_GET['issue']);
+    $prj_id = Issue::getProjectID($_GET['issue_id']);
     if (Customer::hasCustomerIntegration($prj_id)) {
         // check if the selected emails all have sender email addresses that are associated with the issue' customer
         $senders = Support::getSender($_GET['item']);
@@ -86,7 +87,7 @@ if (@$_POST['cat'] == 'associate') {
             $email = Mail_API::getEmailAddress($senders[$i]);
             $sender_emails[$email] = $senders[$i];
         }
-        $customer_id = Issue::getCustomerID($_GET['issue']);
+        $customer_id = Issue::getCustomerID($_GET['issue_id']);
         if (!empty($customer_id)) {
             $contact_emails = array_keys(Customer::getContactEmailAssocList($prj_id, $customer_id));
             $unknown_contacts = array();
