@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: custom_fields.php 3258 2007-02-14 23:25:56Z glen $
+// @(#) $Id: custom_fields.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
@@ -51,9 +52,12 @@ if (!Issue::canAccess($issue_id, Auth::getUserID())) {
 if (@$_POST["cat"] == "update_values") {
     $res = Custom_Field::updateValues();
     $tpl->assign("update_result", $res);
-    $tpl->assign("current_user_prefs", Prefs::get(Auth::getUserID()));
 }
 
+$prefs = Prefs::get(Auth::getUserID());
+$tpl->assign("current_user_prefs", $prefs); // XXX: use 'user_prefs' recursively
+$tpl->assign("user_prefs", $prefs);
+
 $tpl->assign("custom_fields", Custom_Field::getListByIssue($prj_id, $issue_id));
 
 $tpl->displayTemplate();
