@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.auth.php 3394 2007-11-04 08:33:06Z balsdorf $
+// @(#) $Id: class.auth.php 3797 2009-01-12 20:14:39Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -348,18 +349,9 @@ class Auth
     {
         if (empty($email)) {
             return false;
-          } else {
-            $stmt = "SELECT
-                        usr_email
-                     FROM
-                        " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
-                     WHERE
-                        usr_email='" . Misc::escapeString($email) . "'";
-            $info = $GLOBALS["db_api"]->dbh->getOne($stmt);
-            if (PEAR::isError($info)) {
-                Error_Handler::logError(array($info->getMessage(), $info->getDebugInfo()), __FILE__, __LINE__);
-                return false;
-            } elseif (empty($info)) {
+        } else {
+            $usr_id = User::getUserIDByEmail($email, true);
+            if (empty($usr_id)) {
                 return false;
             } else {
                 return true;
@@ -379,23 +371,12 @@ class Auth
      */
     function isCorrectPassword($email, $password)
     {
-        $stmt = "SELECT
-                    usr_password
-                 FROM
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
-                 WHERE
-                    usr_email='" . Misc::escapeString($email) . "' AND
-                    usr_id != " . APP_SYSTEM_USER_ID;
-        $passwd = $GLOBALS["db_api"]->dbh->getOne($stmt);
-        if (PEAR::isError($passwd)) {
-            Error_Handler::logError(array($passwd->getMessage(), $passwd->getDebugInfo()), __FILE__, __LINE__);
+        $usr_id = User::getUserIDByEmail($email, true);
+        $user = User::getDetails($usr_id);
+        if ($user['usr_password'] != Auth::hashPassword($password)) {
             return false;
         } else {
-            if ($passwd != Auth::hashPassword($password)) {
-                return false;
-            } else {
-                return true;
-            }
+            return true;
         }
     }
 
@@ -490,7 +471,7 @@ class Auth
         );
         $cookie = base64_encode(serialize($cookie));
         Auth::setCookie(APP_PROJECT_COOKIE, $cookie, APP_PROJECT_COOKIE_EXPIRE);
-        Auth::createFakeCookie(Auth::getUserID(), $project);
+        $_COOKIE[APP_PROJECT_COOKIE] = $cookie;
     }
 
 
