@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.custom_field.php 3389 2007-10-21 01:33:24Z balsdorf $
+// @(#) $Id: class.custom_field.php 3797 2009-01-12 20:14:39Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -204,12 +205,7 @@ class Custom_Field
                 );
                 if (!in_array($field_types[$fld_id], $option_types)) {
                     // check if this is a date field
-                    if ($field_types[$fld_id] == 'date') {
-                        $value = $value['Year'] . "-" . $value['Month'] . "-" . $value['Day'];
-                        if ($value == '--') {
-                            $value = '';
-                        }
-                    } elseif ($field_types[$fld_id] == 'integer') {
+                    if ($field_types[$fld_id] == 'integer') {
                         $value = Misc::escapeInteger($value);
                     }
                     $fld_db_name = Custom_Field::getDBValueFieldNameByType($field_types[$fld_id]);
@@ -342,9 +338,6 @@ class Custom_Field
     {
         // check if this is a date field
         $fld_details = Custom_Field::getDetails($fld_id);
-        if (($fld_details['fld_type'] == 'date') && (!empty($value))) {
-            $value= $value['Year'] . "-" . $value['Month'] . "-" . $value['Day'];
-        }
         if (!is_array($value)) {
             $value = array($value);
         }
@@ -445,6 +438,14 @@ class Custom_Field
 
 
                     $res[$i]["field_options"] = Custom_Field::getOptions($res[$i]["fld_id"]);
+
+                    // get the default value (if one exists)
+                    $backend = Custom_Field::getBackend($res[$i]["fld_id"]);
+                    if ((is_object($backend)) && (method_exists($backend, 'getDefaultValue'))) {
+                        $res[$i]['default_value'] = $backend->getDefaultValue($res[$i]['fld_id']);
+                    } else {
+                        $res[$i]['default_value'] = '';
+                    }
                 }
                 return $res;
             }
@@ -473,10 +474,14 @@ class Custom_Field
         }
 
         $backend = Custom_Field::getBackend($fld_id);
-        if ((is_object($backend)) && (method_exists($backend, 'getList'))) {
-            $values = $backend->getList($fld_id, false);
-            $returns[$fld_id . $value] = @$values[$value];
-            return @$values[$value];
+        if ((is_object($backend)) && ((method_exists($backend, 'getList')) || (method_exists($backend, 'getOptionValue')))) {
+            if (method_exists($backend, 'getOptionValue')) {
+                return $backend->getOptionValue($fld_id, $value);
+            } else {
+                $values = $backend->getList($fld_id, false);
+                $returns[$fld_id . $value] = @$values[$value];
+                return @$values[$value];
+            }
         } else {
             $stmt = "SELECT
                         cfo_value
@@ -562,6 +567,7 @@ class Custom_Field
      * @param   integer $prj_id The project ID
      * @param   integer $iss_id The issue ID
      * @param   integer $usr_id The ID of the user who is going to be viewing this list.
+     * @param   mixed   $form_type The name of the form this is for or if this is an array the ids of the fields to return
      * @return  array The list of custom fields
      */
     function getListByIssue($prj_id, $iss_id, $usr_id = false, $form_type = false)
@@ -583,6 +589,9 @@ class Custom_Field
                     fld_anonymous_form_required,
                     fld_close_form_required,
                     " . Custom_Field::getDBValueFieldSQL() . " as value,
+                    icf_value,
+                    icf_value_date,
+                    icf_value_integer,
                     fld_min_role
                  FROM
                     (
@@ -598,8 +607,14 @@ class Custom_Field
                     pcf_fld_id=fld_id AND
                     pcf_prj_id=" .  Misc::escapeInteger($prj_id) . " AND
                     fld_min_role <= " . $usr_role;
-        if ($form_type != '') {
-            $stmt .= " AND\nfld_" .  Misc::escapeString($form_type) . "=1";
+        if ($form_type != false) {
+            if (is_array($form_type)) {
+                $stmt .= " AND
+                    fld_id IN(" . join($form_type) . ")";
+            } else {
+                $stmt .= " AND
+                    fld_" .  Misc::escapeString($form_type) . "=1";
+            }
         }
         $stmt .= "
                  ORDER BY
@@ -621,7 +636,7 @@ class Custom_Field
                         $res[$i]["field_options"] = Custom_Field::getOptions($res[$i]["fld_id"]);
 
                         // add the select option to the list of values if it isn't on the list (useful for fields with active and non-active items)
-                        if (!in_array($res[$i]['value'], $res[$i]['field_options'])) {
+                        if ((!empty($res[$i]['original_value'])) && (!isset($res[$i]['field_options'][$res[$i]['original_value']]))) {
                             $res[$i]['field_options'][$res[$i]['original_value']] = Custom_Field::getOptionValue($res[$i]['fld_id'], $res[$i]['original_value']);
                         }
 
@@ -653,6 +668,7 @@ class Custom_Field
                             $fields[$found_index]['field_options'][$original_value] = Custom_Field::getOptionValue($res[$i]['fld_id'], $original_value);
                         }
                     } else {
+                        $res[$i]['value'] = $res[$i][self::getDBValueFieldNameByType($res[$i]['fld_type'])];
                         $fields[] = $res[$i];
                     }
                 }
@@ -1158,17 +1174,15 @@ class Custom_Field
             // update the custom field options, if any
             if (($_POST["field_type"] == "combo") || ($_POST["field_type"] == "multiple")) {
                 $updated_options = array();
-                if (empty($_POST['custom_field_backend'])) {
-                    foreach ($_POST["field_options"] as $option_value) {
-                        $params = Custom_Field::parseParameters($option_value);
-                        if ($params["type"] == 'new') {
-                            Custom_Field::addOptions($_POST["id"], $params["value"]);
-                        } else {
-                            $updated_options[] = $params["id"];
-                            // check if the user is trying to update the value of this option
-                            if ($params["value"] != Custom_Field::getOptionValue($_POST["id"], $params["id"])) {
-                                Custom_Field::updateOption($params["id"], $params["value"]);
-                            }
+                foreach ($_POST["field_options"] as $option_value) {
+                    $params = Custom_Field::parseParameters($option_value);
+                    if ($params["type"] == 'new') {
+                        Custom_Field::addOptions($_POST["id"], $params["value"]);
+                    } else {
+                        $updated_options[] = $params["id"];
+                        // check if the user is trying to update the value of this option
+                        if ($params["value"] != Custom_Field::getOptionValue($_POST["id"], $params["id"])) {
+                            Custom_Field::updateOption($params["id"], $params["value"]);
                         }
                     }
                 }
@@ -1682,7 +1696,7 @@ class Custom_Field
         if ((is_object($backend)) && (method_exists($backend, 'formatValue'))) {
             return $backend->formatValue($value, $fld_id, $issue_id);
         } else {
-            return Link_Filter::processText(Auth::getCurrentProject(), htmlspecialchars($value));
+            return Link_Filter::processText(Auth::getCurrentProject(), Misc::htmlentities($value));
         }
     }
 
