@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.date.php 3246 2007-02-09 09:10:12Z glen $
+// @(#) $Id: class.date.php 3797 2009-01-12 20:14:39Z balsdorf $
 //
 
 // this line needed to make sure PEAR knows all eventum dates are stored as UTC (GMT).
@@ -91,6 +92,60 @@ class Date_API
         }
     }
 
+    /**
+     * Creates a new Date Object initialized to the current date/time in the
+     * GMT timezone by default.  A date optionally
+     * passed in may be in the ISO 8601, TIMESTAMP or UNIXTIME format,
+     * or another Date object.  If no date is passed, the current date/time
+     * is used.
+     *
+     * Format parameter should be one of the specified DATE_FORMAT_* constants:
+     *
+     *  <code>DATE_FORMAT_ISO</code>
+     *                              - 'YYYY-MM-DD HH:MI:SS'
+     *  <code>DATE_FORMAT_ISO_BASIC</code>
+     *                              - 'YYYYMMSSTHHMMSS(Z|(+/-)HHMM)?'
+     *  <code>DATE_FORMAT_ISO_EXTENDED</code>
+     *                              - 'YYYY-MM-SSTHH:MM:SS(Z|(+/-)HH:MM)?'
+     *  <code>DATE_FORMAT_ISO_EXTENDED_MICROTIME</code>
+     *                              - 'YYYY-MM-SSTHH:MM:SS(.S*)?(Z|(+/-)HH:MM)?'
+     *  <code>DATE_FORMAT_TIMESTAMP</code>
+     *                              - 'YYYYMMDDHHMMSS'
+     *  <code>DATE_FORMAT_UNIXTIME'</code>
+     *                              - long integer of the no of seconds since
+     *                                 the Unix Epoch
+     *                                 (1st January 1970 00.00.00 GMT)
+     *
+     * @param mixed $date                optional ISO 8601 date/time to initialize;
+     *                                    or, a Unix time stamp
+     * @param int    $format                 optional format constant
+     *                                        (DATE_FORMAT_*) of the input date.
+     *                                        This parameter is not needed,
+     *                                        except to force the setting of the
+     *                                        date from a Unix time-stamp
+     *                                        (DATE_FORMAT_UNIXTIME).
+     *
+     * @return   Object Date in GMT timezone
+     * @access   public
+     * @see      new Date()
+     */
+    function getDateGMT($date = null, $format = DATE_FORMAT_ISO)
+    {
+        $dt = new Date();
+        $dt->toUTC();
+
+        if (is_a($date, 'Date')) {
+            $dt->copy($date);
+        } else {
+            if (!is_null($date)) {
+                $dt->setDate($date, $format);
+            } else {
+                $dt->setDate(gmdate("Y-m-d H:i:s"));
+            }
+        }
+
+        return $dt;
+    }
 
     /**
      * Returns the current UNIX timestamp in the GMT timezone.
@@ -168,7 +223,7 @@ class Date_API
      * Method used to get the current date in the GMT timezone.
      *
      * @access  public
-     * @return  string The current GMT date
+     * @return  string The current GMT date in DATE_FORMAT_ISO format.
      */
     function getCurrentDateGMT()
     {
@@ -195,6 +250,7 @@ class Date_API
      * @access  public
      * @param   object $date The Date object
      * @return  string The timezone short name
+     * @note    PEAR Date 1.5.0 Includes this method itself.
      */
     function getTimezoneShortName($date)
     {
@@ -221,25 +277,25 @@ class Date_API
         return Date_API::getTimezoneShortName($date);
     }
 
-
     /**
      * Method used to get the formatted date for a specific timestamp
      * and a specific timezone, provided by the user' preference.
      *
      * @access  public
-     * @param   string $timestamp The date timestamp to be formatted
+     * @param   string $ts The date timestamp to be formatted
      * @param   string $timezone The timezone name
      * @return  string
      */
-    function getFormattedDate($timestamp, $timezone = FALSE)
+    function getFormattedDate($ts, $timezone = FALSE)
     {
         if ($timezone === FALSE) {
             $timezone = Date_API::getPreferredTimezone();
         }
-        $date = new Date($timestamp);
+
+        $date = self::getDateGMT($ts);
         // now convert to another timezone and return the date
         $date->convertTZById($timezone);
-        return $date->format('%a, %d %b %Y, %H:%M:%S ') . Date_API::getTimezoneShortName($date);
+        return $date->format('%a, %d %b %Y, %H:%M:%S %Z');
     }
 
 
@@ -304,14 +360,14 @@ class Date_API
 
 
     /**
-     * Method used to convert the user date (that might be in a
-     * specific timezone) to a GMT date.
+     * Method used to convert the user date (that is in a specific timezone) to
+     * a GMT date.
      *
      * @access  public
-     * @param   string $date The user based date
+     * @param   string $date The date in use timezone
      * @return  string The date in the GMT timezone
      */
-    function getDateGMT($date)
+    function convertDateGMT($date)
     {
         $dt = new Date($date);
         $dt->setTZbyID(Date_API::getPreferredTimezone());
@@ -327,7 +383,7 @@ class Date_API
      * @param   integer $timestamp The user based date
      * @return  string The date in the GMT timezone
      */
-    function getDateGMTByTS($timestamp)
+    function convertDateGMTByTS($timestamp)
     {
         return gmdate('Y-m-d H:i:s', $timestamp);
     }
