@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -47,13 +48,14 @@ $avail_langs = array(
     'pl_PL' =>  'Polish',
 #    'en_US' =>  'English',
     'ru_RU' =>  'Russian',
-#    'de_DE' =>  'German',
+    'de_DE' =>  'German',
 #    'fr_FR' =>  'French',
     'it_IT' =>  'Italian',
     'fi_FI' =>  'Finnish',
-#    'es_ES' =>  'Spanish',
+    'es_ES' =>  'Spanish',
 #    'nl_NL' =>  'Dutch',
     'sv_SE' =>  'Swedish',
+    'pt_BR' =>  'Brazilian Portuguese',
 );
 
 class Language
