@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -77,6 +78,8 @@ class Mail_Queue
      */
     function add($recipient, $headers, $body, $save_email_copy = 0, $issue_id = false, $type = '', $sender_usr_id = false, $type_id = false)
     {
+        Workflow::modifyMailQueue(Auth::getCurrentProject(), $recipient, $headers, $body, $issue_id, $type, $sender_usr_id, $type_id);
+
         // avoid sending emails out to users with inactive status
         $recipient_email = Mail_API::getEmailAddress($recipient);
         $usr_id = User::getUserIDByEmail($recipient_email);
@@ -94,10 +97,12 @@ class Mail_Queue
         $reminder_addresses = Reminder::_getReminderAlertAddresses();
 
         // add specialized headers
-        if ((!empty($issue_id)) && ((!empty($to_usr_id)) && (User::getRoleByUser($to_usr_id, Issue::getProjectID($issue_id)) > User::getRoleID("Customer"))) ||
+        if ((!empty($issue_id)) && ((!empty($to_usr_id)) && (User::getRoleByUser($to_usr_id, Issue::getProjectID($issue_id)) != User::getRoleID("Customer"))) ||
                 (@in_array(Mail_API::getEmailAddress($to), $reminder_addresses))) {
             $headers += Mail_API::getSpecializedHeaders($issue_id, $type, $headers, $sender_usr_id);
         }
+        $headers['precedence'] = 'bulk';
+
 
         if (empty($issue_id)) {
             $issue_id = 'null';
@@ -109,12 +114,16 @@ class Mail_Queue
         if (!empty($headers['To'])) {
             $headers['To'] = Mail_API::fixAddressQuoting($headers['To']);
         }
+        // encode headers and add special mime headers
+        $headers = Mime_Helper::encodeHeaders($headers);
 
         $res = Mail_API::prepareHeaders($headers);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return $res;
         }
+
+        // convert array of headers into text headers
         list(,$text_headers) = $res;
 
         $stmt = "INSERT INTO
