@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -275,6 +276,16 @@ class Mime_Helper
     }
 
 
+    function encodeHeaders($headers)
+    {
+        // encodes emails headers
+        foreach ($headers as $name => $value) {
+            $headers[$name] = Mime_Helper::encode($value);
+        }
+        return $headers;
+    }
+
+
     /**
      * Encode a string containing non-ASCII characters according to RFC 2047.
      *
@@ -459,7 +470,7 @@ class Mime_Helper
         if (!is_object($message)) {
             $message = Mime_Helper::decode($message, true);
         }
-        $attachments = Mime_Helper::_getAttachmentDetails($message, TRUE);
+        $attachments = Mime_Helper::_getAttachmentDetails($message, true);
         if (count($attachments) > 0) {
             return true;
         } else {
@@ -481,7 +492,7 @@ class Mime_Helper
         if (!is_object($message)) {
             $message = Mime_Helper::decode($message, true);
         }
-        return Mime_Helper::_getAttachmentDetails($message, TRUE);
+        return Mime_Helper::_getAttachmentDetails($message, true);
     }
 
 
@@ -502,7 +513,7 @@ class Mime_Helper
     }
 
 
-    function _getAttachmentDetails(&$mime_part, $return_body = FALSE, $return_filename = FALSE, $return_cid = FALSE)
+    function _getAttachmentDetails(&$mime_part, $return_body = false, $return_filename = false, $return_cid = false)
     {
         $attachments = array();
         if (isset($mime_part->parts)) {
@@ -526,13 +537,13 @@ class Mime_Helper
         // (since Eventum does not display those embedded within the message)
         if (@$mime_part->ctype_primary == 'image') {
             // if requested, return only the details of a particular filename
-            if (($return_filename != FALSE) && ($mime_part_filename != $return_filename)) {
+            if (($return_filename != false) && ($mime_part_filename != $return_filename)) {
                 return array();
             }
             // if requested, return only the details of
             // a particular attachment CID. Only really needed
             // as hack for inline images
-            if (($return_cid != FALSE) && (@$mime_part->headers['content-id'] != $return_cid)) {
+            if (($return_cid != false) && (@$mime_part->headers['content-id'] != $return_cid)) {
                 return array();
             }
             $found = 1;
@@ -541,7 +552,7 @@ class Mime_Helper
                     (in_array(@strtolower($mime_part->disposition), Mime_Helper::_getValidDispositions())) &&
                     (!empty($mime_part_filename))) {
                 // if requested, return only the details of a particular filename
-                if (($return_filename != FALSE) && ($mime_part_filename != $return_filename)) {
+                if (($return_filename != false) && ($mime_part_filename != $return_filename)) {
                     return array();
                 }
                 $found = 1;
@@ -555,7 +566,7 @@ class Mime_Helper
             );
             // only include the body of the attachment when
             // requested to save some memory
-            if ($return_body == TRUE) {
+            if ($return_body == true) {
                 $t['blob'] = &$mime_part->body;
             }
             $attachments[] = $t;
@@ -575,13 +586,13 @@ class Mime_Helper
      * @param   string $cid The content-id to look for, if any
      * @return  string The full encoded content of the attachment
      */
-    function getAttachment($message, $filename, $cid = FALSE)
+    function getAttachment($message, $filename, $cid = false)
     {
         $parts = array();
         if (!is_object($message)) {
             $message = Mime_Helper::decode($message, true);
         }
-        $details = Mime_Helper::_getAttachmentDetails($message, TRUE, $filename, $cid);
+        $details = Mime_Helper::_getAttachmentDetails($message, true, $filename, $cid);
         if (count($details) == 1) {
             return array(
                 $details[0]['filetype'],
@@ -601,29 +612,57 @@ class Mime_Helper
      * @param   boolean $include_bodies Whether to include the bodies in the return value or not
      * @return  mixed The decoded content of the message
      */
-    function decode($message, $include_bodies = FALSE, $decode_bodies = TRUE)
+    function decode(&$message, $include_bodies = false, $decode_bodies = true)
     {
         // need to fix a pretty annoying bug where if the 'boundary' part of a
         // content-type header is split into another line, the PEAR library would
         // not work correctly. this fix will make the boundary part go to the
         // same line as the content-type one
-        if (preg_match('/^boundary=/m', $message)) {
-            $pattern = "#(Content-Type: multipart/.+); ?\r?\n(boundary=)$#im";
-            $replacement = '$1; $2';
+        if (preg_match("/^(boundary=).*/m", $message)) {
+            $pattern = "/(Content-Type: multipart\/)(.+); ?\r?\n(boundary=)(.*)$/im";
+            $replacement = '$1$2; $3$4';
             $message = preg_replace($pattern, $replacement, $message);
         }
 
         $params = array(
             'crlf'           => "\r\n",
             'include_bodies' => $include_bodies,
-            'decode_headers' => TRUE,
+            'decode_headers' => false,
             'decode_bodies'  => $decode_bodies
         );
         $decode = new Mail_mimeDecode($message);
-        return $decode->decode($params);
+        $email = $decode->decode($params);
+
+        foreach ($email->headers as $name => $value) {
+            if (is_string($value)) {
+                $email->headers[$name] = iconv_mime_decode(trim($value), ICONV_MIME_DECODE_CONTINUE_ON_ERROR, APP_CHARSET);
+            }
+        }
+        if ($include_bodies) {
+            $email->body = Mime_Helper::getMessageBody($email);
+        }
+
+        return $email;
     }
 
 
+    /**
+     * Converts a string from a specified charset to the application charset
+     *
+     * @param   string $string
+     * @param   string $source_charset
+     * @return  string The converted string
+     */
+    function convertString($string, $source_charset)
+    {
+        if (($source_charset == false) || ($source_charset == APP_CHARSET)) {
+            return $string;
+        } else {
+            $res = iconv($source_charset, APP_CHARSET, $string);
+            return $res === false ? $string : $res;
+        }
+    }
+
     /**
      * Method used to parse the decoded object structure of a MIME
      * message into something more manageable.
@@ -646,14 +685,18 @@ class Mime_Helper
                     if (((!empty($obj->disposition)) && (strtolower($obj->disposition) == 'attachment')) || (!empty($obj->d_parameters['filename']))) {
                         @$parts['attachments'][] = $obj->body;
                     } else {
-                        @$parts['text'][] = $obj->body;
+                        $text = Mime_Helper::convertString($obj->body, @$obj->ctype_parameters['charset']);
+                        if (@$obj->ctype_parameters['format'] == 'flowed') {
+                            $text = Mime_Helper::decodeFlowedBodies($text, @$obj->ctype_parameters['delsp']);
+                        }
+                        @$parts['text'][] = $text;
                     }
                     break;
                 case 'text/html':
                     if ((!empty($obj->disposition)) && (strtolower($obj->disposition) == 'attachment')) {
                         @$parts['attachments'][] = $obj->body;
                     } else {
-                        @$parts['html'][] = $obj->body;
+                        @$parts['html'][] = Mime_Helper::convertString($obj->body, @$obj->ctype_parameters['charset']);
                     }
                     break;
                 // special case for Apple Mail
@@ -661,7 +704,7 @@ class Mime_Helper
                     if ((!empty($obj->disposition)) && (strtolower($obj->disposition) == 'attachment')) {
                         @$parts['attachments'][] = $obj->body;
                     } else {
-                        @$parts['html'][] = $obj->body;
+                        @$parts['html'][] = Mime_Helper::convertString($obj->body, @$obj->ctype_parameters['charset']);
                     }
                     break;
                 default:
@@ -750,6 +793,42 @@ class Mime_Helper
         }
         return array();
     }
+
+
+
+    /**
+     * Initial implementation of flowed body handling per RFC 3676. This is probably
+     * not complete but is a start.
+     *
+     * @see     http://www.faqs.org/rfcs/rfc3676.html
+     * @param   text $body The text to "unflow"
+     * @param   string $delsp If spaces should be deleted
+     * @return  string The decoded body
+     */
+    function decodeFlowedBodies($body, $delsp)
+    {
+        if ($delsp == 'yes') {
+            $delsp = true;
+        } else {
+            $delsp = false;
+        }
+
+        $lines = explode("\n", $body);
+
+        $text = '';
+        foreach ($lines as $line) {
+            if (($line != '-- ') && (substr(Misc::removeNewLines($line, true), -1) == ' ')) {
+                if ($delsp) {
+                    $text .= substr(Misc::removeNewLines($line, true), 0, -1);
+                } else {
+                    $text .= Misc::removeNewLines($line, true);
+                }
+            } else {
+                $text .= $line . "\n";
+            }
+        }
+        return $text;
+    }
 }
 
 // benchmarking the included file (aka setup time)
