@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -40,6 +41,9 @@ require_once(APP_INC_PATH . "class.setup.php");
 
 class Misc
 {
+
+    static private $messages = array();
+
     /**
      * Method used to simulate the correct behavior of array_diff().
      *
@@ -712,6 +716,35 @@ class Misc
             return ev_gettext('No');
         }
     }
+
+
+    function removeNewLines($str, $no_space = false)
+    {
+        if ($no_space) {
+            $replacement = '';
+        } else {
+            $replacement = ' ';
+        }
+        return str_replace(array("\n", "\r"), $replacement, $str);
+    }
+
+
+    function htmlentities($var)
+    {
+        return htmlentities($var, ENT_QUOTES, APP_CHARSET);
+    }
+
+
+    function setMessage($msg, $is_error = false)
+    {
+        self::$messages[] = $msg;
+    }
+
+
+    function getMessages()
+    {
+        return self::$messages;
+    }
 }
 
 // benchmarking the included file (aka setup time)
