@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -87,22 +88,30 @@ class Notification
      * @param   string $type The notification type
      * @return  array The list of email addresses
      */
-    function getSubscribedEmails($issue_id, $type)
+    function getSubscribedEmails($issue_id, $type = false)
     {
         $stmt = "SELECT
                     IF(usr_id <> 0, usr_email, sub_email) AS email
                  FROM
                     (
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription,
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription_type
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription";
+        if ($type != false) {
+            $stmt .= ",
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "subscription_type";
+        }
+        $stmt .= "
                     )
                  LEFT JOIN
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  ON
                     usr_id=sub_usr_id
-                 WHERE
+                 WHERE";
+        if ($type != false) {
+            $stmt .= "
                     sbt_sub_id=sub_id AND
-                    sbt_type='" . Misc::escapeString($type) . "' AND
+                    sbt_type='" . Misc::escapeString($type) . "' AND";
+        }
+        $stmt .= "
                     sub_iss_id=" . Misc::escapeInteger($issue_id);
         $res = $GLOBALS["db_api"]->dbh->getCol($stmt);
         if (PEAR::isError($res)) {
@@ -257,9 +266,10 @@ class Notification
         $full_message = $message['full_email'];
         $sender = $message['from'];
         $sender_email = strtolower(Mail_API::getEmailAddress($sender));
+        $structure = Mime_Helper::decode($full_message, true);
 
         // get ID of whoever is sending this.
-        $sender_usr_id = User::getUserIDByEmail($sender_email);
+        $sender_usr_id = User::getUserIDByEmail($sender_email, true);
         if (empty($sender_usr_id)) {
             $sender_usr_id = false;
         }
@@ -299,7 +309,8 @@ class Notification
             }
             if (!empty($email)) {
                 // don't send the email to the same person who sent it
-                if (strtolower(Mail_API::getEmailAddress($email)) == $sender_email) {
+                if ((($sender_usr_id != false) && (!empty($users[$i]["sub_usr_id"])) && ($sender_usr_id == $users[$i]["sub_usr_id"])) ||
+                        (strtolower(Mail_API::getEmailAddress($email)) == $sender_email)) {
                     continue;
                 }
                 $emails[] = $email;
@@ -315,23 +326,13 @@ class Notification
         $from = Notification::getFixedFromHeader($issue_id, $sender, 'issue');
 
         list($_headers, $body) = Mime_Helper::splitBodyHeader($full_message);
-        // strip any 'Received:' headers
-        $_headers = Mail_API::stripHeaders($_headers);
         $header_names = Mime_Helper::getHeaderNames($_headers);
-        // we don't want to keep the (B)Cc list for an eventum-based email
-        $ignore_headers = array(
-            'to',
-            'cc',
-            'bcc'
-        );
+
+        $current_headers = Mail_API::stripHeaders($message['headers']);
         $headers = array();
         // build the headers array required by the smtp library
-        foreach ($message['headers'] as $header_name => $value) {
-            if ((in_array(strtolower($header_name), $ignore_headers)) ||
-                    (!in_array($header_name, array_keys($header_names))) ||
-                    (strstr($header_name, ' '))) {
-                continue;
-            } elseif ($header_name == 'from') {
+        foreach ($current_headers as $header_name => $value) {
+            if ($header_name == 'from') {
                 $headers['From'] = $from;
             } else {
                 if (is_array($value)) {
@@ -354,14 +355,11 @@ class Notification
         @require_once(APP_PEAR_PATH . 'Mail/mime.php');
         foreach ($emails as $to) {
             $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($to));
-            $to = MIME_Helper::encodeAddress($to);
             // add the warning message about replies being blocked or not
             $fixed_body = Mail_API::addWarningMessage($issue_id, $to, $body, $headers);
-            $headers['To'] = $to;
-            $mime = new Mail_mime("\r\n");
-            $hdrs = $mime->headers($headers);
+            $headers['To'] = Mime_Helper::encodeAddress($to);
 
-            Mail_Queue::add($to, $hdrs, $fixed_body, 1, $issue_id, $type, $sender_usr_id, $sup_id);
+            Mail_Queue::add($to, $headers, $fixed_body, 1, $issue_id, $type, $sender_usr_id, $sup_id);
         }
     }
 
@@ -449,9 +447,10 @@ class Notification
                     not_note,
                     not_title,
                     not_unknown_user,
-                    not_blocked_message,
+                    not_full_message,
                     not_message_id,
                     not_parent_id,
+                    not_is_blocked,
                     usr_full_name
                  FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "note,
@@ -761,6 +760,7 @@ class Notification
      */
     function notify($issue_id, $type, $ids = FALSE, $internal_only = FALSE, $extra_recipients = FALSE)
     {
+        $prj_id = Issue::getProjectID($issue_id);
         if ($extra_recipients) {
             $extra = array();
             for ($i = 0; $i < count($extra_recipients); $i++) {
@@ -800,21 +800,23 @@ class Notification
         }
         // prevent the primary customer contact from receiving two emails about the issue being closed
         if ($type == 'closed') {
-            $stmt = "SELECT
-                        iss_customer_contact_id
-                     FROM
-                        " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
-                     WHERE
-                        iss_id=" . Misc::escapeInteger($issue_id);
-            $customer_contact_id = $GLOBALS["db_api"]->dbh->getOne($stmt);
-            if (!empty($customer_contact_id)) {
-                list($contact_email,,) = Customer::getContactLoginDetails(Issue::getProjectID($issue_id), $customer_contact_id);
-                for ($i = 0; $i < count($emails); $i++) {
-                    $email = Mail_API::getEmailAddress($emails[$i]);
-                    if ($email == $contact_email) {
-                        unset($emails[$i]);
-                        $emails = array_values($emails);
-                        break;
+            if (Customer::hasCustomerIntegration($prj_id)) {
+                $stmt = "SELECT
+                            iss_customer_contact_id
+                         FROM
+                            " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
+                         WHERE
+                            iss_id=" . Misc::escapeInteger($issue_id);
+                $customer_contact_id = $GLOBALS["db_api"]->dbh->getOne($stmt);
+                if (!empty($customer_contact_id)) {
+                    list($contact_email,,) = Customer::getContactLoginDetails($prj_id, $customer_contact_id);
+                    for ($i = 0; $i < count($emails); $i++) {
+                        $email = Mail_API::getEmailAddress($emails[$i]);
+                        if ($email == $contact_email) {
+                            unset($emails[$i]);
+                            $emails = array_values($emails);
+                            break;
+                        }
                     }
                 }
             }
@@ -909,13 +911,15 @@ class Notification
         $tpl->setTemplate('notifications/' . $type . '.tpl.text');
         $tpl->bulkAssign(array(
             "app_title"    => Misc::getToolCaption(),
-            "data"         => $data
+            "data"         => $data,
+            "current_user" => User::getFullName(Auth::getUserID()),
         ));
 
         $setup = Setup::load();
         $final_type = $type;
         $sender_usr_id = false;
         $threading_headers = Mail_API::getBaseThreadingHeaders($issue_id);
+        $emails = array_unique($emails);
         for ($i = 0; $i < count($emails); $i++) {
 
             $can_access = true;
@@ -961,7 +965,7 @@ class Notification
 
             if ($type == 'notes') {
                 // special handling of blocked messages
-                if (!empty($data['note']['not_blocked_message'])) {
+                if ($data['note']['not_is_blocked'] == 1) {
                     $subject = ev_gettext('BLOCKED');
                     $final_type = 'blocked_email';
                 }
@@ -985,7 +989,7 @@ class Notification
                 // don't add the "[#3333] Note: " prefix to messages that already have that in the subject line
                 if (strstr($extra_subject, "[#$issue_id] $subject: ")) {
                     $pos = strpos($extra_subject, "[#$issue_id] $subject: ");
-                    $full_subject = substr($extra_subject, 4);
+                    $full_subject = substr($extra_subject, $pos);
                 } else {
                     $full_subject = "[#$issue_id] $subject: $extra_subject";
                 }
@@ -1244,7 +1248,9 @@ class Notification
                 $tpl->setTemplate('notifications/new_auto_created_issue.tpl.text');
                 $tpl->bulkAssign(array(
                     "data"        => $data,
-                    "sender_name" => Mail_API::getName($recipient)
+                    "sender_name" => Mail_API::getName($recipient),
+                    "app_title"   => Misc::getToolCaption(),
+                    'recipient_name'    => Mail_API::getName($recipient),
                 ));
                 $email_details = Support::getEmailDetails(Email_Account::getAccountByEmail($sup_id), $sup_id);
                 $tpl->assign(array(
@@ -1270,7 +1276,7 @@ class Notification
                 $setup = $mail->getSMTPSettings();
                 $from = Notification::getFixedFromHeader($issue_id, $setup["from"], 'issue');
                 $mail->setHeaders(Mail_API::getBaseThreadingHeaders($issue_id));
-                $mail->send($from, $recipient, 'New Issue Created', 1, $issue_id, 'email_converted_to_issue');
+                $mail->send($from, $recipient, "[#$issue_id] Issue Created: " . $data['iss_summary'], 1, $issue_id, 'email_converted_to_issue');
             }
             Language::restore();
             return $recipient_emails;
@@ -1278,47 +1284,6 @@ class Notification
     }
 
 
-    /**
-     * Method used to send an IRC notification about changes in the assignment
-     * list of an issue.
-     *
-     * @access  public
-     * @param   integer $issue_id The issue ID
-     * @param   integer $usr_id The person who is performing this change
-     * @param   array $old The old issue assignment list
-     * @param   array $new The new issue assignment list
-     * @param   boolean $is_remote Whether this change was made remotely or not
-     */
-    function notifyIRCAssignmentChange($issue_id, $usr_id, $old, $new, $is_remote = FALSE)
-    {
-        // do not notify about clearing the assignment of an issue
-        if (count($new) == 0) {
-            return false;
-        }
-        // only notify on irc if the assignment is being done to more than one person,
-        // or in the case of a one-person-assignment-change, if the person doing it
-        // is different than the actual assignee
-        if ((count($new) == 1) && ($new[0] == $usr_id)) {
-            return false;
-        }
-        $assign_diff = Misc::arrayDiff($old, $new);
-        if ((count($new) != count($old)) || (count($assign_diff) > 0)) {
-            $notice = "Issue #$issue_id ";
-            if ($is_remote) {
-                $notice .= "remotely ";
-            }
-            if (count($old) == 0) {
-                $old_assignees = '[empty]';
-            } else {
-                $old_assignees = implode(', ', User::getFullName($old));
-            }
-            $notice .= "updated (Old Assignment: " . $old_assignees .
-                    "; New Assignment: " . implode(', ', User::getFullName($new)) . ")";
-            Notification::notifyIRC(Issue::getProjectID($issue_id), $notice, $issue_id);
-        }
-    }
-
-
     /**
      * Method used to send an IRC notification about a blocked email that was
      * saved into an internal note.
@@ -1555,8 +1520,12 @@ class Notification
         $prj_id = Issue::getProjectID($issue_id);
         $emails = array();
         for ($i = 0; $i < count($users); $i++) {
+            if ($users[$i] == Auth::getUserID()) {
+                continue;
+            }
             $prefs = Prefs::get($users[$i]);
-            if ((!empty($prefs)) && (@$prefs["receive_assigned_emails"][$prj_id]) && ($users[$i] != Auth::getUserID())) {
+            if ((!empty($prefs)) && (isset($prefs["receive_assigned_emails"][$prj_id])) &&
+                    ($prefs["receive_assigned_emails"][$prj_id]) && ($users[$i] != Auth::getUserID())) {
                 $emails[] = User::getFromHeader($users[$i]);
             }
         }
@@ -1946,10 +1915,19 @@ class Notification
      * actions.
      *
      * @access  public
+     * @param   integer $issue_id The ID of the issue the user is being subscribed too
+     * @param   string  $email The email address of the user to be subscribed
+     * @param   string  $source The source of this call, "add_unknown_user", "self_assign", "remote_assign", "anon_issue", "issue_update", "issue_from_email", "new_issue", "note", "add_extra_recipients"
      * @return  array The list of default notification actions
      */
-    function getDefaultActions()
+    function getDefaultActions($issue_id = false, $email = false, $source = false)
     {
+        $prj_id = Auth::getCurrentProject();
+        $workflow = Workflow::getNotificationActions($prj_id, $issue_id, $email, $source);
+        if (!is_null($workflow)) {
+            return $workflow;
+        }
+
         $actions = array();
         $setup = Setup::load();
 
@@ -2057,11 +2035,16 @@ class Notification
      */
     function subscribeEmail($usr_id, $issue_id, $form_email, $actions)
     {
-        $form_email = strtolower(Mail_API::getEmailAddress($form_email));
+        $form_email = Mail_API::getEmailAddress($form_email);
+        if (!is_string($form_email)) {
+            return -1;
+        }
+
+        $form_email = strtolower($form_email);
         // first check if this is an actual user or just an email address
-        $user_emails = User::getAssocEmailList();
-        if (in_array($form_email, array_keys($user_emails))) {
-            return Notification::subscribeUser($usr_id, $issue_id, $user_emails[$form_email], $actions);
+        $sub_usr_id = User::getUserIDByEmail($form_email, true);
+        if (!empty($sub_usr_id)) {
+            return Notification::subscribeUser($usr_id, $issue_id, $sub_usr_id, $actions);
         }
 
         $issue_id = Misc::escapeInteger($issue_id);
@@ -2169,7 +2152,7 @@ class Notification
         list($issue_id, $usr_id) = $GLOBALS["db_api"]->dbh->getRow($stmt);
 
         $email = strtolower(Mail_API::getEmailAddress($_POST["email"]));
-        $usr_id = User::getUserIDByEmail($email);
+        $usr_id = User::getUserIDByEmail($email, true);
         if (!empty($usr_id)) {
             $email = '';
         } else {
