@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.project.php 3246 2007-02-09 09:10:12Z glen $
+// @(#) $Id: class.project.php 3797 2009-01-12 20:14:39Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -434,6 +435,7 @@ class Project
                     prj_initial_sta_id=" . Misc::escapeInteger($_POST["initial_status"]) . ",
                     prj_outgoing_sender_name='" . Misc::escapeString($_POST["outgoing_sender_name"]) . "',
                     prj_outgoing_sender_email='" . Misc::escapeString($_POST["outgoing_sender_email"]) . "',
+                    prj_mail_aliases='" . Misc::escapeString($_POST["mail_aliases"]) . "',
                     prj_remote_invocation='" . Misc::escapeString($_POST["remote_invocation"]) . "',
                     prj_segregate_reporter='" . Misc::escapeString($_POST["segregate_reporter"]) . "',
                     prj_customer_backend='" . Misc::escapeString($_POST["customer_backend"]) . "',
@@ -539,6 +541,7 @@ class Project
                     prj_initial_sta_id,
                     prj_outgoing_sender_name,
                     prj_outgoing_sender_email,
+                    prj_mail_aliases,
                     prj_remote_invocation,
                     prj_customer_backend,
                     prj_workflow_backend
@@ -550,6 +553,7 @@ class Project
                     " . Misc::escapeInteger($_POST["initial_status"]) . ",
                     '" . Misc::escapeString($_POST["outgoing_sender_name"]) . "',
                     '" . Misc::escapeString($_POST["outgoing_sender_email"]) . "',
+                    '" . Misc::escapeString($_POST["mail_aliases"]) . "',
                     '" . Misc::escapeString($_POST["remote_invocation"]) . "',
                     '" . Misc::escapeString($_POST["customer_backend"]) . "',
                     '" . Misc::escapeString($_POST["workflow_backend"]) . "'
