@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.report.php 3510 2007-12-17 19:56:20Z balsdorf $
+// @(#) $Id: class.report.php 3803 2009-01-13 18:28:04Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -650,7 +651,7 @@ class Report
                         iss_customer_id,
                         count(DISTINCT(iss_id)) as row_count,
                         iss_private,
-                        " . Custom_Field::getDBValueFieldSQL() . " as field_value";
+                        fld_id";
             if ($label_field != '') {
                 $sql .= ",
                         $label_field as interval_label";
@@ -670,7 +671,7 @@ class Report
                         fld_id = icf_fld_id AND";
             if (count($options) > 0) {
                 $sql .=
-                        "cfo_id = icf_value AND";
+                        " cfo_id = icf_value AND";
             }
             $sql .= "
                         icf_iss_id = iss_id AND
@@ -713,6 +714,9 @@ class Report
                     }'));
                 }
             }
+            for ($i = 0; $i < count($res); $i++) {
+                $res[$i]['field_value'] = Custom_Field::getDisplayValue($res[$i]['iss_id'], $res[$i]['fld_id']);
+            }
             return $res;
         }
 
