@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -122,7 +123,7 @@ class Routing
             return array(78, ev_gettext("Error: Please provide the email account ID.") . "\n");
         }
 
-        $body = Mime_Helper::getMessageBody($structure);
+        $body = $structure->body;
 
         // hack for clients that set more then one from header
         if (is_array($structure->headers['from'])) {
@@ -295,17 +296,14 @@ class Routing
 
         $prj_id = Issue::getProjectID($issue_id);
         // check if the sender is allowed in this issue' project and if it is an internal user
-        $users = Project::getUserEmailAssocList($prj_id, 'active', User::getRoleID('Customer'));
-        $sender_email = strtolower(Mail_API::getEmailAddress($structure->headers['from']));
-        $user_emails = array_map('strtolower', array_values($users));
-        if (!in_array($sender_email, $user_emails)) {
+        $sender_usr_id = User::getUserIDByEmail(strtolower(Mail_API::getEmailAddress($structure->headers['from'])), true);
+        if ((empty($sender_usr_id)) || (User::getRoleByUser($sender_usr_id, $prj_id) < User::getRoleID('Standard User'))) {
             return array(77, ev_gettext("Error: The sender of this email is not allowed in the project associated with issue #$issue_id.") . "\n");
         }
 
-        Auth::createFakeCookie(User::getUserIDByEmail($sender_email), $prj_id);
+        Auth::createFakeCookie($sender_usr_id, $prj_id);
 
         // parse the Cc: list, if any, and add these internal users to the issue notification list
-        $users = array_flip($users);
         $addresses = array();
         $to_addresses = Mail_API::getEmailAddresses(@$structure->headers['to']);
         if (count($to_addresses)) {
@@ -317,12 +315,13 @@ class Routing
         }
         $cc_users = array();
         foreach ($addresses as $email) {
-            if (in_array(strtolower($email), $user_emails)) {
-                $cc_users[] = $users[strtolower($email)];
+            $cc_usr_id = User::getUserIDByEmail(strtolower($email), true);
+            if ((!empty($cc_usr_id)) && (User::getRoleByUser($cc_usr_id, $prj_id) >= User::getRoleID("Standard User"))) {
+                $cc_users[] = $cc_usr_id;
             }
         }
 
-        $body = Mime_Helper::getMessageBody($structure);
+        $body = $structure->body;
         $reference_msg_id = Mail_API::getReferenceMessageID($headers);
         if (!empty($reference_msg_id)) {
             $parent_id = Note::getIDByMessageID($reference_msg_id);
@@ -343,7 +342,7 @@ class Routing
         // add the full email to the note if there are any attachments
         // this is needed because the front end code will display attachment links
         if (Mime_Helper::hasAttachments($structure)) {
-            $_POST['blocked_msg'] = $full_message;
+            $_POST['full_message'] = $full_message;
         }
         $res = Note::insert(Auth::getUserID(), $issue_id, false, false);
         // need to handle attachments coming from notes as well
@@ -414,16 +413,17 @@ class Routing
 
         $prj_id = Issue::getProjectID($issue_id);
         // check if the sender is allowed in this issue' project and if it is an internal user
-        $users = Project::getUserEmailAssocList($prj_id, 'active', User::getRoleID('Customer'));
-        $sender_email = strtolower(Mail_API::getEmailAddress($structure->headers['from']));
-        $user_emails = array_map('strtolower', array_values($users));
-        if (!in_array($sender_email, $user_emails)) {
-            return array(77, ev_gettext("Error: The sender of this email is not allowed in the project associated with issue #") . "$issue_id.\n");
+        $sender_usr_id = User::getUserIDByEmail(strtolower(Mail_API::getEmailAddress($structure->headers['from'])), true);
+        if (!empty($sender_usr_id)) {
+            $sender_role = User::getRoleByUser($sender_usr_id, $prj_id);
+            if ($sender_role < User::getRoleID('Standard User')) {
+                return array(77, ev_gettext("Error: The sender of this email is not allowed in the project associated with issue #$issue_id.") . "\n");
+            }
         }
 
         Auth::createFakeCookie(User::getUserIDByEmail($sender_email), $prj_id);
 
-        $body = Mime_Helper::getMessageBody($structure);
+        $body = $structure->body;
 
         Draft::saveEmail($issue_id, @$structure->headers['to'], @$structure->headers['cc'], @$structure->headers['subject'], $body, false, false, false);
         // XXX: need to handle attachments coming from drafts as well?
