@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.time_tracking.php 3322 2007-04-25 13:08:08Z glen $
+// @(#) $Id: class.time_tracking.php 3797 2009-01-12 20:14:39Z balsdorf $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -423,7 +424,7 @@ class Time_Tracking
                 $_POST["date"]["Day"], $_POST["date"]["Hour"],
                 $_POST["date"]["Minute"], 0);
             // convert the date to GMT timezone
-            $created_date = Date_API::getDateGMT($created_date);
+            $created_date = Date_API::convertDateGMT($created_date);
         } else {
             $created_date = Date_API::getCurrentDateGMT();
         }
