@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: class.user.php 3308 2007-04-17 01:32:48Z balsdorf $
+// @(#) $Id: class.user.php 3804 2009-01-14 14:04:56Z glen $
 //
 
 require_once(APP_INC_PATH . "class.error_handler.php");
@@ -406,12 +407,18 @@ class User
      *
      * @access  public
      * @param   string $email The email address associated with the user account
+     * @param   boolean $check_aliases If user aliases should be checked as well.
      * @return  integer The user ID
      */
-    function getUserIDByEmail($email)
+    function getUserIDByEmail($email, $check_aliases = false)
     {
         static $returns;
 
+        if (!is_string($email)) {
+            Error_Handler::logError('$email parameter is not a string: '.gettype($email), __FILE__, __LINE__);
+            return null;
+        }
+
         if (!empty($returns[$email])) {
             return $returns[$email];
         }
@@ -427,8 +434,12 @@ class User
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return "";
         } else {
-            $returns[$email] = $res;
-            return $res;
+            if ((empty($res)) && ($check_aliases)) {
+                $returns[$email] = User::getUserIDByAlias($email);
+            } else {
+                $returns[$email] = $res;
+            }
+            return $returns[$email];
         }
     }
 
@@ -668,6 +679,7 @@ class User
             $roles =  Project::getAssocList($usr_id, false, true);
             $res["projects"] = @array_keys($roles);
             $res["roles"] = $roles;
+            $res['group'] = Group::getName($res['usr_grp_id']);
             $returns[$usr_id] = $res;
             return $res;
         }
@@ -989,12 +1001,13 @@ class User
         if ($_POST["id"] == APP_SYSTEM_USER_ID) {
             return 1;
         }
-
+        $group_id = ($_POST["grp_id"]) ? Misc::escapeInteger($_POST["grp_id"]) : 'NULL';
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  SET
                     usr_full_name='" . Misc::escapeString($_POST["full_name"]) . "',
-                    usr_email='" . Misc::escapeString($_POST["email"]) . "'";
+                    usr_email='"     . Misc::escapeString($_POST["email"])     . "',
+                    usr_grp_id="     . $group_id;
         if (!empty($_POST["password"])) {
             $stmt .= ",
                     usr_password='" . Auth::hashPassword($_POST["password"]) . "'";
@@ -1430,6 +1443,82 @@ class User
     }
 
 
+    function getAliases($usr_id)
+    {
+        $sql = "SELECT
+                    ual_email
+                FROM
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user_alias
+                WHERE
+                    ual_usr_id = " . Misc::escapeInteger($usr_id);
+        $res = $GLOBALS["db_api"]->dbh->getCol($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return array();
+        }
+        return $res;
+    }
+
+    function addAlias($usr_id, $email)
+    {
+        // see if alias belongs to a user right now
+        $email_usr_id = User::getUserIDByEmail($email);
+        if (!empty($email_usr_id)) {
+            return false;
+        }
+
+        $existing_alias_usr_id = User::getUserIDByAlias($email);
+        if (!empty($existing_alias_usr_id)) {
+            return false;
+        }
+
+        $sql = "INSERT INTO
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user_alias
+                SET
+                    ual_usr_id = " . Misc::escapeInteger($usr_id) . ",
+                    ual_email = '" . Misc::escapeString($email) . "'";
+        $res = $GLOBALS["db_api"]->dbh->query($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return false;
+        }
+        return true;
+    }
+
+
+    function removeAlias($usr_id, $email)
+    {
+        $sql = "DELETE FROM
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user_alias
+                WHERE
+                    ual_usr_id = " . Misc::escapeInteger($usr_id) . " AND
+                    ual_email = '" . Misc::escapeString($email) . "'";
+        $res = $GLOBALS["db_api"]->dbh->query($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return false;
+        }
+        return true;
+    }
+
+
+    function getUserIDByAlias($email)
+    {
+        $sql = "SELECT
+                    ual_usr_id
+                FROM
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user_alias
+                WHERE
+                    ual_email = '" . Misc::escapeString($email) . "'";
+        $res = $GLOBALS["db_api"]->dbh->getOne($sql);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return '';
+        }
+        return $res;
+    }
+
+
     function setLocalizedRoles()
     {
         $GLOBALS['localized_roles'] = array(
