@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -151,6 +152,25 @@ class Workflow
     }
 
 
+    /**
+     * Called before an issue is updated.
+     *
+     * @param   integer $prj_id The project ID
+     * @param   integer $issue_id The ID of the issue
+     * @param   integer $usr_id The ID of the user changing the issue.
+     * @param   array   $changes
+     * @return  mixed. True to continue, anything else to cancel the change and return the value
+     */
+    function preIssueUpdated($prj_id, $issue_id, $usr_id, &$changes)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return true;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->preIssueUpdated($prj_id, $issue_id, $usr_id, $changes);
+    }
+
+
     /**
      * Called when an issue is assigned.
      *
@@ -487,7 +507,7 @@ class Workflow
 
 
     /**
-     * Called at the begining of the email download process. If it returns true, the
+     * Called at the begining of the email download process. If it returns -1, the
      * rest of the email code will not be executed.
      *
      * @param   integer $prj_id The project ID
@@ -496,15 +516,16 @@ class Workflow
      * @param   integer $num The sequential email number
      * @param   string $message The complete email message
      * @param   object $email An object containing the decoded email
+     * @param   object $structure An object containing the decoded email
      * @return  mixed null by default, -1 if the rest of the email script should not be processed.
      */
-    function preEmailDownload($prj_id, $info, $mbox, $num, &$message, &$email)
+    function preEmailDownload($prj_id, $info, $mbox, $num, &$message, &$email, &$structure)
     {
         if (!Workflow::hasWorkflowIntegration($prj_id)) {
             return null;
         }
         $backend =& Workflow::_getBackend($prj_id);
-        return $backend->preEmailDownload($prj_id, $info, $mbox, $num, $message, $email);
+        return $backend->preEmailDownload($prj_id, $info, $mbox, $num, $message, $email, $structure);
     }
 
 
@@ -522,4 +543,126 @@ class Workflow
         $backend =& Workflow::_getBackend($prj_id);
         return $backend->shouldAutoAddToNotificationList($prj_id);
     }
+
+
+    /**
+     * Returns the issue ID to associate a new email with, null to use the default logic and "new" to create
+     * a new issue.
+     *
+     * @param   integer $prj_id The ID of the project
+     * @param   array   $info An array of info about the email account.
+     * @param   string  $headers The headers of the email.
+     * @param   string  $message_body The body of the message.
+     * @param   string  $date The date this message was sent
+     * @param   string  $from The name and email address of the sender.
+     * @param   string  $subject The subject of this message.
+     * @param   array   $to An array of to addresses
+     * @param   array   $cc An array of cc addresses
+     */
+    function getIssueIDforNewEmail($prj_id, $info, $headers, $message_body, $date, $from, $subject, $to, $cc)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return null;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->getIssueIDforNewEmail($prj_id, $info, $headers, $message_body, $date, $from, $subject, $to, $cc);
+    }
+
+
+    /**
+     * Modifies the content of the message being added to the mail queue.
+     *
+     * @param   integer $prj_id
+     * @param   string $recipient
+     * @param   array $headers
+     * @param   string $body
+     * @param   integer $issue_id
+     * @param   string $type The type of message this is.
+     * @param   integer $sender_usr_id The id of the user sending this email.
+     * @param   integer $type_id The ID of the event that triggered this notification (issue_id, sup_id, not_id, etc)
+     */
+    function modifyMailQueue($prj_id, &$recipient, &$headers, &$body, $issue_id, $type, $sender_usr_id, $type_id)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return true;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->modifyMailQueue($prj_id, $recipient, $headers, $body, $issue_id, $type, $sender_usr_id, $type_id);
+    }
+
+
+    /**
+     * Called before the status changes. Parameters are passed by reference so the values can be changed.
+     *
+     * @param   integer $prj_id
+     * @param   integer $issue_id
+     * @param   integer $status_id
+     * @param   boolean $notify
+     * @return  boolean true to continue normal processing, anything else to cancel and return value.
+     */
+    function preStatusChange($prj_id, &$issue_id, &$status_id, &$notify)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return true;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->preStatusChange($prj_id, $issue_id, $status_id, $notify);
+    }
+
+
+    /**
+     * Called at the start of many pages. After the includes and maybe some other code this
+     * method is called to do whatever you want. Eventually this will be called on many pages.
+     *
+     * @param   integer $prj_id The project ID
+     * @param   string $page_name The name of the page
+     * @return  null
+     */
+    function prePage($prj_id, $page_name)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return true;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->prePage($prj_id, $page_name);
+    }
+
+
+    /**
+     * Called to determine which actions to subscribe a new user too.
+     *
+     * @see     Notification::getDefaultActions()
+     * @param   integer $prj_id The project ID
+     * @param   integer $issue_id The ID of the issue
+     * @param   string  $email The email address of the user being added
+     * @param   string  $source The source of this call
+     * @return  array   an array of actions
+     */
+    function getNotificationActions($prj_id, $issue_id, $email, $source)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return null;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->getNotificationActions($prj_id, $issue_id, $email, $source);
+    }
+
+
+    /**
+     * Returns which "issue fields" should be displayed in a given location.
+     *
+     * @see     class.issue_field.php
+     * @param   integer $prj_id The project ID
+     * @param   integer $issue_id The ID of the issue
+     * @param   string  $location The location to display these fields at
+     * @return  array   an array of fields to display and their associated options
+     */
+    function getIssueFieldsToDisplay($prj_id, $issue_id, $location)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return array();
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->getIssueFieldsToDisplay($prj_id, $issue_id, $location);
+    }
 }
\ No newline at end of file
