@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -41,7 +42,7 @@ ini_set('memory_limit', '128M');
 ini_set('session.cache_limiter', 'nocache');
 
 define('APP_URL', 'http://www.mysql.com/products/eventum/');
-define('APP_VERSION', '2.1.1');
+define('APP_VERSION', '2.2');
 
 // define base path
 define('APP_PATH', realpath(dirname(__FILE__)) . '/');
@@ -83,6 +84,10 @@ if (!defined('APP_SETUP_FILE')) {
     define('APP_SETUP_FILE', APP_CONFIG_PATH . 'setup.php');
 }
 
+if (!defined('APP_SQL_PATCHES_PATH')) {
+    define('APP_SQL_PATCHES_PATH', APP_PATH . 'misc/upgrade/patches');
+}
+
 if (!defined('APP_LOG_PATH')) {
     define('APP_LOG_PATH', APP_PATH . 'logs/');
 }
