@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: list.php 3258 2007-02-14 23:25:56Z glen $
+// @(#) $Id: list.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "db_access.php");
@@ -90,20 +91,6 @@ if ((count($groups) > 0) && (Auth::getCurrentRole() > User::getRoleID("Customer"
 }
 $assign_options += $users;
 
-// get display values for custom fields
-$custom_fields_display = array();
-if ((is_array($options['custom_field'])) && (count($options['custom_field']) > 0)) {
-    foreach ($options['custom_field'] as $fld_id => $search_value) {
-        if (empty($search_value)) {
-            continue;
-        }
-        $field = Custom_Field::getDetails($fld_id);
-        if (($field['fld_type'] == 'combo') || ($field['fld_type'] == 'multiple')) {
-            $custom_fields_display[$fld_id] = join(', ', Custom_Field::getOptions($fld_id, $search_value));
-        }
-    }
-}
-
 $list = Issue::getListing($prj_id, $options, $pagerRow, $rows);
 $tpl->assign("list", $list["list"]);
 $tpl->assign("list_info", $list["info"]);
@@ -112,21 +99,23 @@ $tpl->assign("csv_data", base64_encode(@$list["csv"]));
 $tpl->assign("columns", Display_Column::getColumnsToDisplay($prj_id, 'list_issues'));
 $tpl->assign("priorities", Priority::getAssocList($prj_id));
 $tpl->assign("status", Status::getAssocStatusList($prj_id));
-$tpl->assign("open_status", Status::getAssocStatusList($prj_id, false));
-$tpl->assign("users", $users);
 $tpl->assign("assign_options", $assign_options);
 $tpl->assign("custom", Filter::getAssocList($prj_id));
 $tpl->assign("csts", Filter::getListing(true));
-$tpl->assign("filter_info", Filter::getFiltersInfo());
+$tpl->assign("active_filters", Filter::getActiveFilters($options));
 $tpl->assign("categories", Category::getAssocList($prj_id));
 $tpl->assign("releases", Release::getAssocList($prj_id, true));
-$tpl->assign("available_releases", Release::getAssocList($prj_id));
-$tpl->assign("groups", $groups);
-$tpl->assign("custom_fields_display", $custom_fields_display);
 $tpl->assign("reporters", Project::getReporters($prj_id));
 
 $prefs = Prefs::get($usr_id);
 $tpl->assign("refresh_rate", $prefs['list_refresh_rate'] * 60);
 $tpl->assign("refresh_page", "list.php");
 
+// items needed for bulk update tool
+if (Auth::getCurrentRole() > User::getRoleID("Developer")) {
+    $tpl->assign("users", $users);
+    $tpl->assign("open_status", Status::getAssocStatusList($prj_id, false));
+    $tpl->assign("available_releases", Release::getAssocList($prj_id));
+}
+
 $tpl->displayTemplate();
