@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: login.php 3258 2007-02-14 23:25:56Z glen $
+// @(#) $Id: login.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "db_access.php");
@@ -51,6 +52,10 @@ if (!Auth::isCorrectPassword($_POST["email"], $_POST["passwd"])) {
     Auth::saveLoginAttempt($_POST["email"], 'failure', 'wrong password');
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=3&email=" . $_POST["email"]);
 }
+
+// handle aliases since the user is now authenticated
+$_POST['email'] = User::getEmail(User::getUserIDByEmail($_POST['email'], true));
+
 // check if this user did already confirm his account
 if (Auth::isPendingUser($_POST["email"])) {
     Auth::saveLoginAttempt($_POST["email"], 'failure', 'pending user');
