@@ -1,8 +1,8 @@
 <?php
-include_once("../../config.inc.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.lock.php");
-include_once(APP_INC_PATH . "db_access.php");
+require_once(dirname(__FILE__) . '/../../init.php');
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.lock.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 Auth::checkAuthentication(APP_COOKIE);
 
@@ -21,11 +21,11 @@ if (!empty($process_id)) {
 }
 
 Lock::release('irc_bot');
-$start = `cd /var/www/html/eventum/misc/irc/;php -q bot.php > /dev/null &`;
+$start = `cd /var/www/html/eventum/misc/irc/;php bot.php > /dev/null &`;
 if (!empty($start)) {
     echo "Error: $start<br />\n";
 }
 
 ?>
 <hr>
-If there are no error messages above, the bot should have been successfully restarted.
\ No newline at end of file
+If there are no error messages above, the bot should have been successfully restarted.
