@@ -4,7 +4,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,13 +26,10 @@
 // +----------------------------------------------------------------------+
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
-//
-// @(#) $Id: process_cvs_commits.php 3502 2007-12-05 10:34:30Z glen $
-
 
 // URL to your Eventum installation.
 // https is supported transparently by PHP 5 if you have openssl module enabled.
-$eventum_url = 'http://rabbit.impleo.net/';
+$eventum_url = 'http://eventum.example.com/';
 
 
 //
