@@ -12,8 +12,13 @@ $stmt = "SELECT
             prj_title
          FROM
             " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project";
-$projects = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
-if (PEAR::isError($projects) || count($projects) < 1) {
+$res = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
+if (PEAR::isError($res)) {
+	echo 'ERROR: ', $res->getMessage(), ': ', $res->getDebugInfo(), "\n";
+    exit(1);
+}
+$projects = $res;
+if (count($projects) < 1) {
     echo "Error getting projects or no projects defined.<pre>";
     print_r($priorities);
     exit(1);
@@ -25,8 +30,13 @@ $stmt = "SELECT
             ere_title
          FROM
             " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "email_response";
-$responses = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
-if (PEAR::isError($responses) || count($responses) < 1) {
+$res = $GLOBALS["db_api"]->dbh->getAssoc($stmt);
+if (PEAR::isError($res)) {
+	echo 'ERROR: ', $res->getMessage(), ': ', $res->getDebugInfo(), "\n";
+    exit(1);
+}
+$responses = $res;
+if (count($responses) < 1) {
     echo "Error getting canned responses or none defined.<pre>";
     print_r($responses);
     exit(1);
@@ -43,10 +53,11 @@ foreach ($responses as $ere_id => $ere_title) {
                     )";
         $res = $GLOBALS['db_api']->dbh->query($stmt);
         if (DB::isError($res)) {
-            echo "<pre>";var_dump($res);exit(1);
+			echo 'ERROR: ', $res->getMessage(), ': ', $res->getDebugInfo(), "\n";
+			exit(1);
         }
     }
 }
 
 ?>
-done
\ No newline at end of file
+done
