@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,16 +23,13 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: João Prado Maia <jpm@mysql.com>                             |
-// +----------------------------------------------------------------------+
-//
-// @(#) $Id: post_note.php 3258 2007-02-14 23:25:56Z glen $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
 require_once(APP_INC_PATH . "class.auth.php");
 require_once(APP_INC_PATH . "class.user.php");
 require_once(APP_INC_PATH . "class.note.php");
+require_once(APP_INC_PATH . "class.issue_field.php");
 require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
@@ -53,6 +51,8 @@ if ((!Issue::canAccess($issue_id, $usr_id)) || (Auth::getCurrentRole() <= User::
     exit;
 }
 
+Workflow::prePage($prj_id, 'post_note');
+
 if (@$_POST["cat"] == "post_note") {
     // change status
     if (!@empty($_POST['new_status'])) {
@@ -64,6 +64,7 @@ if (@$_POST["cat"] == "post_note") {
     }
 
     $res = Note::insert($usr_id, $issue_id);
+    Issue_Field::updateValues($issue_id, 'post_note', @$_REQUEST['issue_field']);
     $tpl->assign("post_result", $res);
     // enter the time tracking entry about this phone support entry
     if (!empty($_POST['time_spent'])) {
@@ -99,7 +100,8 @@ $tpl->assign(array(
     'current_issue_status'  =>  Issue::getStatusID($issue_id),
     'time_categories'    => Time_Tracking::getAssocCategories(),
     'note_category_id'   => Time_Tracking::getCategoryID('Note Discussion'),
-    'reply_subject'      => $reply_subject
+    'reply_subject'      => $reply_subject,
+    'issue_fields'       => Issue_Field::getDisplayData($issue_id, 'post_note'),
 ));
 
 $tpl->displayTemplate();
