@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: preferences.php 3468 2007-11-12 20:55:27Z glen $
+// @(#) $Id: preferences.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 // skip language init if we're saving language
 if (@$_POST['language']) {
@@ -41,8 +42,10 @@ require_once(APP_INC_PATH . "db_access.php");
 
 // must do Language::setPreference before template is initialized
 if (@$_POST["cat"] == "update_account") {
-    $res = User::setLang(Auth::getUserID(), $_POST['language']);
-    Language::setPreference();
+    if (isset($_POST['language'])) {
+        $res = User::setLang(Auth::getUserID(), $_POST['language']);
+        Language::setPreference();
+    }
 }
 
 $tpl = new Template_API();
@@ -53,7 +56,6 @@ Auth::checkAuthentication(APP_COOKIE);
 $usr_id = Auth::getUserID();
 
 if (@$_POST["cat"] == "update_account") {
-    $tpl->assign('update_lang_result', $res);
     $res = Prefs::set($usr_id);
     $tpl->assign('update_account_result', $res);
     User::updateSMS($usr_id, @$_POST['sms_email']);
@@ -75,6 +77,7 @@ if (empty($prefs)) {
     $prefs = Setup::load();
 }
 $tpl->assign("user_prefs", $prefs);
+$tpl->assign("user_info", User::getDetails($usr_id));
 $tpl->assign("assigned_projects", Project::getAssocList($usr_id, false, true));
 $tpl->assign("zones", Date_API::getTimezoneList());
 $tpl->assign('avail_langs', Language::getAvailableLanguages());
