@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: self_assign.php 3258 2007-02-14 23:25:56Z glen $
+// @(#) $Id: self_assign.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
@@ -59,7 +60,7 @@ if ((count($assigned_user_ids) > 0) && (empty($_REQUEST["target"]))) {
     }
     $res = Issue::addUserAssociation($usr_id, $issue_id, $usr_id);
     $tpl->assign("self_assign_result", $res);
-    Notification::subscribeUser($usr_id, $issue_id, $usr_id, Notification::getDefaultActions());
+    Notification::subscribeUser($usr_id, $issue_id, $usr_id, Notification::getDefaultActions($issue_id, User::getEmail($usr_id), 'self_assign'));
     Workflow::handleAssignment($prj_id, $issue_id, $usr_id);
 }
 
