@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: stats_chart.php 3380 2007-09-26 04:30:54Z balsdorf $
+// @(#) $Id: stats_chart.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "db_access.php");
@@ -57,7 +58,8 @@ if (isset($_REQUEST['hide_closed'])) {
 // Some data
 $colors = array();
 if ($_GET["plot"] == "status") {
-    $rgb = new RGB();
+    $fake = false;
+    $rgb = new RGB($fake);
     $data = Stats::getAssocStatus($hide_closed);
     $graph_title = ev_gettext("Issues by Status");
     foreach ($data as $sta_title => $trash) {
