@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: update.php 3437 2007-11-10 00:52:16Z glen $
+// @(#) $Id: update.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
@@ -49,6 +50,7 @@ $associated_projects = @array_keys(Project::getAssocList($usr_id));
 
 $tpl = new Template_API();
 $tpl->setTemplate("update.tpl.html");
+$tpl->assign("user_prefs", Prefs::get($usr_id));
 
 Auth::checkAuthentication(APP_COOKIE);
 
@@ -59,6 +61,8 @@ if (empty($issue_id)) {
     exit;
 }
 
+Workflow::prePage($prj_id, 'update');
+
 // check if the requested issue is a part of the 'current' project. If it doesn't
 // check if issue exists in another project and if it does, switch projects
 $iss_prj_id = Issue::getProjectID($issue_id);
@@ -119,7 +123,6 @@ if (($role_id == User::getRoleID('customer')) && (User::getCustomerID($usr_id) !
         "releases"     => $releases,
         "resolutions"  => Resolution::getAssocList(),
         "users"        => Project::getUserAssocList($prj_id, 'active', User::getRoleID('Customer')),
-        "issues"       => Issue::getColList("iss_id <> $issue_id"),
         "one_week_ts"  => time() + (7 * DAY),
         "allow_unassigned_issues"   =>  @$setup["allow_unassigned_issues"],
         "groups"       => Group::getAssocList($prj_id),
