@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: view.php 3258 2007-02-14 23:25:56Z glen $
+// @(#) $Id: view.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
@@ -55,7 +56,6 @@ $role_id = Auth::getCurrentRole();
 $associated_projects = @array_keys(Project::getAssocList($usr_id));
 
 @$issue_id = $_POST["issue_id"] ? $_POST["issue_id"] : $_GET["id"];
-$tpl->assign("extra_title", "Issue #$issue_id Details");
 
 // check if the requested issue is a part of the 'current' project. If it doesn't
 // check if issue exists in another project and if it does, switch projects
@@ -69,14 +69,20 @@ if ((!empty($iss_prj_id)) && ($iss_prj_id != $prj_id) && (in_array($iss_prj_id,
 }
 
 $details = Issue::getDetails($issue_id);
+$tpl->assign("extra_title", ev_gettext('Issue #%1$s Details', $issue_id));
 $tpl->assign("issue", $details);
 
 // in the case of a customer user, also need to check if that customer has access to this issue
 if (($role_id == User::getRoleID('customer')) && (User::getCustomerID($usr_id) != $details['iss_customer_id'])) {
     $tpl->assign("auth_customer", 'denied');
+
 } elseif (!Issue::canAccess($issue_id, $usr_id)) {
     $tpl->assign("auth_user", 'denied');
+
 } else {
+    // now that we access to the issue, add more verbose HTML <title>
+    $tpl->assign("extra_title", ev_gettext('#%1$s - %2$s', $issue_id, $details['iss_summary']));
+
     $associated_projects = @array_keys(Project::getAssocList($usr_id));
     if ((empty($details)) || ($details['iss_prj_id'] != $prj_id)) {
         $tpl->assign('issue', '');
