@@ -3,7 +3,8 @@
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
+// | Copyright (c) 2003 - 2008 MySQL AB                                   |
+// | Copyright (c) 2008 - 2009 Sun Microsystem Inc.                       |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -25,7 +26,7 @@
 // | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: view_email.php 3338 2007-06-19 21:49:22Z balsdorf $
+// @(#) $Id: view_email.php 3797 2009-01-12 20:14:39Z balsdorf $
 
 require_once(dirname(__FILE__) . "/init.php");
 require_once(APP_INC_PATH . "class.template.php");
@@ -75,10 +76,4 @@ if (@$_GET['cat'] == 'list_emails') {
     ));
 }
 
-// set the page charset to whatever is set on this email
-$charset = Mime_Helper::getCharacterSet($email['seb_full_email']);
-if (!empty($charset)) {
-    header("Content-Type: text/html; charset=" . $charset);
-}
-
 $tpl->displayTemplate();
